==> qmmp-0.9.10.tar.bz2: qmmp-0.9.10/src/plugins/Input/opus/translations/opus_plugin_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="47"/>
        <source>Opus Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="50"/>
        <source>Ogg Opus Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="124"/>
        <source>About Opus Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="125"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="126"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="127"/>
        <source>This plugin includes code from TagLib library</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Input/opus/translations/opus_plugin_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="43"/>
        <source>Opus Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="46"/>
        <source>Ogg Opus Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="129"/>
        <source>About Opus Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="130"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="131"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="132"/>
        <source>This plugin includes code from TagLib library</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="49"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
